vasabase library

A pure Dart SDK for Vasabase.

This package provides clients for Authentication, Database, Storage, and Realtime.

Classes

AuthClient
The main client for interacting with the Authentication API.
PostgrestClient
The main client for interacting with the database.
PostgrestFilterBuilder
A builder class for adding filters to a PostgREST query.
PostgrestQueryBuilder
A builder class for constructing PostgREST queries.
RealtimeClient
Session
StorageClient
StorageFileApi
User
VasabaseClient

Exceptions / Errors

PostgrestException
An exception thrown by the PostgREST client.