RealtimeClient class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headersProvider
→ Map<
String, String> Function() -
final
- projectRef → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
final
Methods
-
connect(
) → void -
disconnect(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
on(
String table) → Stream< Map< String, dynamic> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited